/*
 * Copyright 2010 Mihai Niculescu <q.quark@gmail.com>
 *
 * This file is part of EqualX Project (https://launchpad.net/equalx/)
 *
 * EqualX is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EqualX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QApplication>
#include <QDrag>
#include <QGraphicsSceneMouseEvent>
#include <QList>
#include <QMimeData>
#include <QBuffer>
#include <QPixmap>
#include <QUrl>

#include <QDebug>
#include "defines.h"
#include "EquationPixmapItem.h"

EquationPixmapItem::EquationPixmapItem(QGraphicsItem * parent)
    : QGraphicsPixmapItem(parent)
{
    dragging = false;
    setAcceptHoverEvents(true);
}

void EquationPixmapItem::setPixmap(const QString &file)
{
    imageFile = file;

    QGraphicsPixmapItem::setPixmap( QPixmap(file) );

}


void EquationPixmapItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
{
    QGraphicsPixmapItem::hoverEnterEvent(event);
    setCursor(Qt::OpenHandCursor);
}

void EquationPixmapItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
{
    QGraphicsPixmapItem::hoverLeaveEvent(event);
    unsetCursor();

}


void EquationPixmapItem::mousePressEvent( QGraphicsSceneMouseEvent * event)
{
    if (event->button() == Qt::LeftButton ){
        dragStartPosition = event->pos();
        qDebug() << "Equation: click " << dragStartPosition;
    }

}

void EquationPixmapItem::mouseMoveEvent( QGraphicsSceneMouseEvent * event)
{
    qDebug() << "Equation: drag begin...";

    if (!(event->buttons() & Qt::LeftButton))
        return;

    if (QLineF(event->screenPos(), event->buttonDownScreenPos(Qt::LeftButton)).length() < QApplication::startDragDistance()) {
        return;
    }

    qDebug() << "Equation: dragging " << imageFile;

   QList<QUrl> urls;
   QUrl fileUrl = QUrl::fromLocalFile(imageFile);

   urls.append( fileUrl );


    QMimeData *mimeData = new QMimeData;

    mimeData->setUrls(urls);


    QDrag *drag = new QDrag(event->widget() );
    drag->setMimeData(mimeData);
    drag->setPixmap( pixmap() );
    drag->setHotSpot(dragStartPosition.toPoint() );

    drag->exec(Qt::CopyAction);

    dragging = true;


}

void EquationPixmapItem::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
{
    dragging = false;
}
