/*
* Copyright 2009 EMBITEL (http://www.embitel.com)
* 
* This file is part of Color Picker Project.
* 
* Color Picker is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation
* 
* Color Picker is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with Color Picker. If not, see <http://www.gnu.org/licenses/>.
*/

#include "WidgetColorPicker.h"
#include <QColorDialog>

WidgetColorPicker::WidgetColorPicker(QWidget *parent):QWidget(parent)
{
    setupUi(this);
    init();
}

WidgetColorPicker::~WidgetColorPicker()
{

}

void WidgetColorPicker::init()
{
    comboBox->setMaxCount(21);

    disconnect(comboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(on_comboBox_currentIndexChanged(int)));
    comboBox->addItem("Custom Color..");
    comboBox->addItem(createIcon("#FFFFFF"),"transparent",QColor(1,1,1,0));
    comboBox->addItem(createIcon("#000000"),"black",QColor("#000000"));
    comboBox->addItem(createIcon("#FFFFFF"),"white",QColor("#FFFFFF"));
    comboBox->addItem(createIcon("#FF0000"),"red",QColor("#FF0000"));
    comboBox->addItem(createIcon("#800000"),"dark red",QColor("#800000"));
    comboBox->addItem(createIcon("#00ff00"),"green",QColor("#00ff00"));
    comboBox->addItem(createIcon("#008000"),"dark green",QColor("#008000"));
    comboBox->addItem(createIcon("#0000ff"),"blue",QColor("#0000ff"));
    comboBox->addItem(createIcon("#000080"),"dark blue",QColor("#000080"));
    comboBox->addItem(createIcon("#00ffff"),"cyan",QColor("#00ffff"));
    comboBox->addItem(createIcon("#ff00ff"),"magenta",QColor("#ff00ff"));
    comboBox->addItem(createIcon("#ffff00"),"yellow",QColor("#ffff00"));
    comboBox->addItem(createIcon("#a0a0a4"),"gray",QColor("#a0a0a4"));
    comboBox->addItem(createIcon("#808080"),"dark gray",QColor("#808080"));
    comboBox->addItem(createIcon("#c0c0c0"),"light gray",QColor("#c0c0c0"));

    m_Color = QColor(0,0,0,0);
    m_ColorName = "transparent";
    comboBox->setCurrentIndex(1);
    connect(comboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(on_comboBox_currentIndexChanged(int)));
}

QIcon WidgetColorPicker::createIcon(QString colorName)
{
    QPixmap iconPixmap(32,32);
    iconPixmap.fill(QColor(colorName));
    QIcon itemIcon(iconPixmap);
    return itemIcon;
}

void WidgetColorPicker::on_comboBox_currentIndexChanged(int index)
{
    if(index==0)
    {
        m_Color = QColorDialog::getColor(m_Color,this);
        m_ColorName = m_Color.name();
        addColor(m_Color);
    }
    else
    {
        m_ColorName = comboBox->itemText(index);
        m_Color     = comboBox->itemData(index).value<QColor>();
    }

    emit colorSelectionChanged(m_ColorName);
    emit colorSelectionChanged(m_Color);
}

void WidgetColorPicker::setCurrentIndex(int i)
{
    comboBox->setCurrentIndex(i);
}

void WidgetColorPicker::setColorName(QString colorName)
{
    if(!colorName.isEmpty())
    {
        if(QColor(colorName).isValid())
        {
            m_ColorName = colorName;
            m_Color = QColor(colorName);
            addColor(colorName);
        }
    }
}

void WidgetColorPicker::setColor(QColor color)
{
    if(color.isValid())
    {
        m_ColorName = color.name();
        m_Color = color;
        addColor(color);
    }
}

QColor WidgetColorPicker::getColor()
{
    return m_Color;
}

QString WidgetColorPicker::getColorName()
{
    return m_ColorName;
}

QString WidgetColorPicker::getColorString()
{

    if( QString::compare(m_ColorName, "transparent", Qt::CaseInsensitive) == 0 )
        return "transparent";

    QString colorStr = QString("%1,%2,%3").arg(m_Color.redF()).arg(m_Color.greenF()).arg(m_Color.blueF());


    return colorStr;
}

void WidgetColorPicker::addColor(QColor color)
{
    int index;
    if((index = comboBox->findData(color)) > -1)
        comboBox->setCurrentIndex(index);
    else
    {
        QString colorName = color.name().toUpper();
        comboBox->insertItem(1,createIcon(colorName),colorName,color);
        comboBox->setCurrentIndex(1);
    }
}

void WidgetColorPicker::addColor(QString colorName)
{
    int index;

    if((index = comboBox->findText(colorName)) > -1)
        comboBox->setCurrentIndex(index);
    else
    {
        comboBox->insertItem(1,createIcon(colorName),colorName,QColor(colorName));
        comboBox->setCurrentIndex(1);
    }
}
