#include "WidgetFind.h"
#include "ui_widgetFind.h"

WidgetFind::WidgetFind(QWidget *parent) :
        QWidget(parent),
        ui(new Ui::WidgetFind)
{
    ui->setupUi(this);


    setSignals();

    ui->findEntry->setFocus();
}

WidgetFind::~WidgetFind()
{
    delete ui;
}

void WidgetFind::changeEvent(QEvent *e)
{
    QWidget::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

QString  WidgetFind::getFindExpr() const
{
    return ui->findEntry->text();
}

void WidgetFind::onClose()
{
    emit closing();

    QWidget::close();
}

void WidgetFind::onChangedFindText(const QString &expr)
{
    bool findable = ! expr.isEmpty();

    ui->findNextButton->setEnabled(findable);
    ui->findHLButton->setEnabled(findable);
    ui->findPrevButton->setEnabled(findable);


    QTextDocument::FindFlags searchFlags;

    if(ui->findOptMatchCase->isChecked() ) searchFlags = searchFlags | QTextDocument::FindCaseSensitively;


    emit changedFindText(expr);

    if( ui->findHLButton->isChecked() ){
        emit findAll(expr, searchFlags);
    }
    else{
        emit find();
        emit find(expr, searchFlags);
    }
}

void WidgetFind::onPressedFindNext()
{
    QString expr = ui->findEntry->text();
    QTextDocument::FindFlags searchFlags;

    if(ui->findOptMatchCase->isChecked() ) searchFlags = searchFlags | QTextDocument::FindCaseSensitively;

    emit find();
    emit find(expr, searchFlags);
}

void WidgetFind::onPressedFindPrev()
{
    QString expr = ui->findEntry->text();
    QTextDocument::FindFlags searchFlags;

    if(ui->findOptMatchCase->isChecked() ) searchFlags = searchFlags | QTextDocument::FindCaseSensitively;

    searchFlags = searchFlags | QTextDocument::FindBackward;

    emit find();
    emit find(expr, searchFlags);
}

void WidgetFind::onToggledHighlight(bool activate)
{
    QString expr = ui->findEntry->text();
    QTextDocument::FindFlags searchFlags;

    if(ui->findOptMatchCase->isChecked() ) searchFlags = searchFlags | QTextDocument::FindCaseSensitively;

    emit toggledHighlight(activate);

    if(activate)
        emit findAll(expr, searchFlags);
    else
        emit findAll("", searchFlags);
}

void WidgetFind::setFindExpr(const QString &expr)
{
    ui->findEntry->setText(expr);

}

void WidgetFind::setSignals()
{
    connect(ui->findEntry, SIGNAL(textChanged(QString)), this, SLOT(onChangedFindText(QString)) );
    connect(ui->findHLButton, SIGNAL(toggled(bool)), this, SLOT(onToggledHighlight(bool)) );
    connect(ui->findNextButton, SIGNAL(released()), this, SLOT(onPressedFindNext()) );
    connect(ui->findPrevButton, SIGNAL(released()), this, SLOT(onPressedFindPrev()) );

    connect(ui->findCloseButton, SIGNAL(clicked()), this, SLOT(onClose()) );

}

void WidgetFind::show()
{
    QWidget::show();

    ui->findEntry->setFocus();
    ui->findHLButton->setChecked(false);

}
