/*
 * Copyright 2010 Mihai Niculescu <q.quark@gmail.com>
 *
 * This file is part of EqualX Project (https://launchpad.net/equalx/)
 *
 * EqualX is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EqualX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QAction>
#include <QGridLayout>
#include <QToolButton>
#include <QTimer>

#include "WidgetToolMenu.h"
#include "WidgetFramePopup.h"

WidgetToolMenu::WidgetToolMenu(QWidget *parent)
        : QFrame(parent)
{
    setupUi(this);
    init(1, 1);
}

WidgetToolMenu::WidgetToolMenu( int nVisibleCols, int nVisibleRows, QWidget *parent)
        : QFrame(parent)
{
    setupUi(this);

    init(nVisibleRows, nVisibleCols);
}

WidgetToolMenu::~WidgetToolMenu()
{

}

void WidgetToolMenu::init(int nrows, int ncols )
{
    m_numCols = ncols-1;
    m_numRows = nrows-1;
    m_curCol = 0;
    m_curRow = 0;

    m_iconSize = QSize(20, 20);

    m_gridFrame = new QGridLayout;
    m_gridFrame->setContentsMargins(3 , 3, 3, 3);
    m_gridFrame->setSpacing(0);

    
    m_frameMenu = new WidgetFramePopup(this);

    m_buttonShowMenu = new QToolButton(this);
    m_buttonShowMenu->setMaximumWidth(15);
    m_buttonShowMenu->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
    m_buttonShowMenu->setArrowType(Qt::DownArrow);
    m_buttonShowMenu->setPopupMode(QToolButton::InstantPopup);
    m_buttonShowMenu->setToolButtonStyle(Qt::ToolButtonIconOnly);
    m_buttonShowMenu->setAutoRaise(true);

    QHBoxLayout *hbox = new QHBoxLayout(this);
    hbox->setContentsMargins(0, 0,0,0);
    hbox->setSpacing(0);



    hbox->addLayout(m_gridFrame);
    hbox->addWidget(m_buttonShowMenu);

    setLayout(hbox);

    connect(m_buttonShowMenu, SIGNAL(clicked()), this, SLOT(showMenu()) );


}

void WidgetToolMenu::addAction(QAction *action)
{
    QToolButton * button = new QToolButton;
    button->setDefaultAction(action);
    button->setAutoRaise(true);
    button->setIconSize(m_iconSize);
    connect(button, SIGNAL(triggered(QAction*)), this, SLOT(actionTriggered(QAction*)) );

    addButton(button);

    QFrame::addAction(action);
}

void WidgetToolMenu::addActions(QList<QAction*> actions)
{
    for(int i=0; i < actions.size(); ++i){
        addAction( actions.at(i) );

    }
}

void WidgetToolMenu::addButton(QWidget *button)
{
    // first add Button to widget
    if(m_curCol <= m_numCols){
        if(m_curRow <= m_numRows){
            // add this button in widget
            m_gridFrame->addWidget(button, m_curRow, m_curCol);

        }
        else {
            // add this button in Menu
            m_frameMenu->addWidget(button, m_curRow-m_numRows, m_curCol);
        }

    } else {
        m_curCol = 0;
        m_curRow++;

        if(m_curRow <= m_numRows){
            // add this button in widget
            m_gridFrame->addWidget(button, m_curRow, m_curCol);

        }
        else{
            // add this button in Menu
            m_frameMenu->addWidget(button, m_curRow-m_numRows, m_curCol);
        }
    }
    m_curCol++;

}

void WidgetToolMenu::actionTriggered(QAction *action)
{
   emit triggered(action);
}

/*
void WidgetToolMenu::mousePressEvent(QMouseEvent *event)
{
   if(!m_frameMenu->isEmpty() && m_frameMenu->isHidden() ){
        m_frameMenu->show();

    }

   QFrame::mousePressEvent(event);

}
*/

void WidgetToolMenu::showMenu()
{

    if(!m_frameMenu->isEmpty() && m_frameMenu->isHidden() ){
        m_frameMenu->popup();

    }

}

void WidgetToolMenu::hideMenu()
{
    if(!m_frameMenu->underMouse() && !underMouse() ){
        m_frameMenu->hide();

    }
}

